===============================
networking-arista
===============================

Arista Networking drivers

* Free software: Apache license
* Source: http://git.openstack.org/cgit/openstack/networking-arista

Features
--------

* TODO
